<?php

// 共通インクルードファイル
require_once('common.php');

/**
 * class CommodityForm
 * 入力フォームクラス
 * jp.co.veritrans.sample.CommodityFormより移植
 */
class CommodityForm extends ActionForm {

    /**
     * ログクラス
     */
    private $log = null;
    /**
     * PayNowID使用フラグ
     */
    private $paynowidFlag = null;
    /**
     * 会員ID
     */
    private $accountId = null;
    /**
     * 決済方法
     * @var string
     */
    private $settlementType = null;
    /**
     * 決済方法サブタイプ
     * @var string
     */
    private $settlementSubType = null;
    /**
     * マーチャントID
     * @var string
     */
    private $merchantId = null;
    /**
     * 取引ID
     * @var string
     */
    private $orderId = null;
    /**
     * SessionID
     * @var string
     */
    private $sessionId = null;
    /**
     * 購入金額
     * @var string
     */
    private $amount = null;
    /**
     * カード売上フラグ
     * @var string
     */
    private $cardCaptureFlag = null;
    /**
     * モバイルEdy用ショップ名
     * @var string
     */
    private $shopName = null;
    /**
     * Suica用商品名
     * @var string
     */
    private $screenTitle = null;
    /**
     * 請求内容
     * @var string
     */
    private $contents = null;
    /**
     * 請求内容カナ
     * @var string
     */
    private $contentsKana = null;
    /**
     * 支払取消期限
     * @var string
     */
    private $timelimitOfCancel = null;
    /**
     * マーチャント生成ハッシュ値
     * @var string
     */
    private $merchanthash = null;
    /**
     * 決済結果通知先URL
     * @var string
     */
    private $finishPaymentAccessUrl = null;
    /**
     * 決済完了後戻りURL
     * @var string
     */
    private $finishPaymentReturnUrl = null;
    /**
     * 未決済時戻りURL
     * @var string
     */
    private $unfinishPaymentReturnUrl = null;
    /**
     * 決済エラー時戻りURL
     * @var string
     */
    private $errorPaymentReturnUrl = null;
    /**
     * 言語選択可否フラグ
     * @var string
     */
    private $langEnableFlag = null;
    /**
     * 使用言語
     * @var string
     */
    private $lang = null;
    /**
     * ダミー取引フラグ
     * @var string
     */
    private $dummyPaymentFlag = null;
    /**
     * 送料
     * @var string
     */
    private $shippingAmount = null;
    /**
     * 商品合計金額
     * @var string
     */
    private $commodityAmount = null;
    /**
     * 配送先郵便番号(先頭3桁)
     * @var string
     */
    private $shippingZipCode1 = null;
    /**
     * 配送先郵便番号(末尾4桁)
     * @var string
     */
    private $shippingZipCode2 = null;
    /**
     * 商品ID
     * @var string
     */
    private $commodityId1 = null;
    /**
     * 商品ID
     * @var string
     */
    private $commodityId2 = null;
    /**
     * 商品ID
     * @var string
     */
    private $commodityId3 = null;
    /**
     * 単価
     * @var string
     */
    private $commodityUnit1 = null;
    /**
     * 単価
     * @var string
     */
    private $commodityUnit2 = null;
    /**
     * 単価
     * @var string
     */
    private $commodityUnit3 = null;
    /**
     * 個数
     * @var string
     */
    private $commodityNum1 = null;
    /**
     * 個数
     * @var string
     */
    private $commodityNum2 = null;
    /**
     * 個数
     * @var string
     */
    private $commodityNum3 = null;
    /**
     * 商品名
     * @var string
     */
    private $commodityName1 = null;
    /**
     * 商品名
     * @var string
     */
    private $commodityName2 = null;
    /**
     * 商品名
     * @var string
     */
    private $commodityName3 = null;
    /**
     * JANコード
     * @var string
     */
    private $commodityJanCode1 = null;
    /**
     * JANコード
     * @var string
     */
    private $commodityJanCode2 = null;
    /**
     * JANコード
     * @var string
     */
    private $commodityJanCode3 = null;
    /**
     * 登録時振込番号
     * @var string
     */
    private $entryTransferNumber= null;
    /**
     * 振込期限
     * @var string
     */
    private $transferExpiredDate= null;
    /**
     * 口座管理方式
     * @var string
     */
    private $accountManageType= null;
    /**
     * 支店コード
     * @var string
     */
    private $branchCode= null;
    /**
     * 口座番号
     * @var string
     */
    private $accountNumber= null;
    /**
     * 銀行口座関連付け拒否フラグ
     * @var string
     */
    private $rejectBankAccount= null;
    /**
     * ブラウザ側暗号鍵
     * @var string
     */
    private $settlementKey1A = null;
    /**
     * 決済結果
     * @var string
     */
    private $settlementComplete = null;
    /**
     * 商品IDのマップ
     * @var array
     */
    private $idmap = array();
    /**
     * 商品名のマップ
     * @var array
     */
    private $namemap = array();
    /**
     * 個数のマップ
     * @var array
     */
    private $nummap = array();
    /**
     * 単価のマップ
     * @var array
     */
    private $unitmap = array();
    /**
     * JANコードのマップ
     * @var array
     */
    private $janCodemap = array();

    /**
     * コンストラクタ
     */
    public function __construct() {
        parent::__construct();
        $this->log = new Logger(__CLASS__);
    }

    /**
     * PayNowID使用フラグの設定
     * @param paynowidFlag PayNowID使用フラグ
     */
    public function setPaynowidFlag($paynowidFlag) {
        $this->paynowidFlag = $paynowidFlag;
    }

    /**
     * PayNowID使用フラグの取得
     * @return PayNowID使用フラグ
     */
    public function getPaynowidFlag() {
        return $this->paynowidFlag;
    }

    /**
     * 会員IDの設定
     * @param accountId 会員ID
     */
    public function setAccountId($accountId) {
        $this->accountId = $accountId;
    }

    /**
     * 会員IDの取得
     * @return 会員ID
     */
    public function getAccountId() {
        return $this->accountId;
    }

    /**
     * 配送先郵便番号の取得
     * @return 配送先郵便番号
     */
    public function getShippingZipCode() {
        return $this->shippingZipCode1 . $this->shippingZipCode2;
    }

    /**
     * 商品IDの設定
     * @param commodityId1 商品ID１
     */
    public function setCommodityId1($commodityId1) {
        $this->commodityId1 = $commodityId1;
        $this->idmap[1] = $commodityId1;
    }

    /**
     * 商品IDの取得
     * @return 商品ID１
     */
    public function getCommodityId1() {
        return $this->commodityId1;
    }

    /**
     * 商品IDの設定
     * @param commodityId1 商品ID2
     */
    public function setCommodityId2($commodityId2) {
        $this->commodityId2 = $commodityId2;
        $this->idmap[2] = $commodityId2;
    }

    /**
     * 商品IDの取得
     * @return 商品ID2
     */
    public function getCommodityId2() {
        return $this->commodityId2;
    }

    /**
     * 商品IDの設定
     * @param commodityId1 商品ID3
     */
    public function setCommodityId3($commodityId3) {
        $this->commodityId3 = $commodityId3;
        $this->idmap[3] = $commodityId3;
    }

    /**
     * 商品IDの取得
     * @return 商品ID3
     */
    public function getCommodityId3() {
        return $this->commodityId3;
    }

    /**
     * 商品名の設定
     * @param commodityName1 商品名１
     */
    public function setCommodityName1($commodityName1) {
        $this->commodityName1 = $commodityName1;
        $this->namemap[1] = $commodityName1;
    }

    /**
     * 商品名の取得
     * @return 商品名
     */
    public function getCommodityName1() {
        return $this->commodityName1;
    }

    /**
     * 商品名の設定
     * @param commodityName2 商品名２
     */
    public function setCommodityName2($commodityName2) {
        $this->commodityName2 = $commodityName2;
        $this->namemap[2] = $commodityName2;
    }

    /**
     * 商品名の取得
     * @return 商品名
     */
    public function getCommodityName2() {
        return $this->commodityName2;
    }

    /**
     * 商品名の設定
     * @param commodityName3 商品名３
     */
    public function setCommodityName3($commodityName3) {
        $this->commodityName3 = $commodityName3;
        $this->namemap[3] = $commodityName3;
    }

    /**
     * 商品名の取得
     * @return 商品名
     */
    public function getCommodityName3() {
        return $this->commodityName3;
    }

    /**
     * 個数の設定
     * @param commodityNum1 個数１
     */
    public function setCommodityNum1($commodityNum1) {
        $this->commodityNum1 = $commodityNum1;
        $this->nummap[1] = $commodityNum1;
    }

    /**
     * 個数の取得
     * @return 個数１
     */
    public function getCommodityNum1() {
        return $this->commodityNum1;
    }

    /**
     * 個数の設定
     * @param commodityNum2 個数
     */
    public function setCommodityNum2($commodityNum2) {
        $this->commodityNum2 = $commodityNum2;
        $this->nummap[2] = $commodityNum2;
    }

    /**
     * 個数の取得
     * @return 個数
     */
    public function getCommodityNum2() {
        return $this->commodityNum2;
    }

    /**
     * 個数の設定
     * @param commodityNum3 個数
     */
    public function setCommodityNum3($commodityNum3) {
        $this->commodityNum3 = $commodityNum3;
        $this->nummap[3] = $commodityNum3;
    }

    /**
     * 個数の取得
     * @return 個数
     */
    public function getCommodityNum3() {
        return $this->commodityNum3;
    }

    /**
     * 価格の設定
     * @param commodityUnit1 価格
     */
    public function setCommodityUnit1($commodityUnit1) {
        $this->commodityUnit1 = $commodityUnit1;
        $this->unitmap[1] = $commodityUnit1;
    }

    /**
     * 価格の設定
     * @param commodityUnit2 価格
     */
    public function setCommodityUnit2($commodityUnit2) {
        $this->commodityUnit2 = $commodityUnit2;
        $this->unitmap[2] = $commodityUnit2;
    }

    /**
     * 価格の設定
     * @param commodityUnit3 価格
     */
    public function setCommodityUnit3($commodityUnit3) {
        $this->commodityUnit3 = $commodityUnit3;
        $this->unitmap[3] = $commodityUnit3;
    }

    /**
     * 価格の取得
     * @return 価格
     */
    public function getCommodityUnit1() {
        return $this->commodityUnit1;
    }

    /**
     * 価格の取得
     * @return 価格
     */
    public function getCommodityUnit2() {
        return $this->commodityUnit2;
    }

    /**
     * 価格の取得
     * @return 価格
     */
    public function getCommodityUnit3() {
        return $this->commodityUnit3;
    }

    /**
     * JANコードの設定
     * @param commodityJanCode1 JANコード１
     */
    public function setCommodityJanCode1($commodityJanCode1) {
        $this->commodityJanCode1 = $commodityJanCode1;
        $this->janCodemap[1] = $commodityJanCode1;
    }

    /**
     * JANコードの取得
     * @return JANコード１
     */
    public function getCommodityJanCode1() {
        return $this->commodityJanCode1;
    }

    /**
     * JANコードの設定
     * @param commodityJanCode2 JANコード2
     */
    public function setCommodityJanCode2($commodityJanCode2) {
        $this->commodityJanCode2 = $commodityJanCode2;
        $this->janCodemap[2] = $commodityJanCode2;
    }

    /**
     * JANコードの取得
     * @return JANコード2
     */
    public function getCommodityJanCode2() {
        return $this->commodityJanCode2;
    }

    /**
     * JANコードの設定
     * @param commodityJanCode3 JANコード3
     */
    public function setCommodityJanCode3($commodityJanCode3) {
        $this->commodityJanCode3 = $commodityJanCode3;
        $this->janCodemap[3] = $commodityJanCode3;
    }

    /**
     * JANコードの取得
     * @return JANコード3
     */
    public function getCommodityJanCode3() {
        return $this->commodityJanCode3;
    }

    /**
     * 登録時振込番号の設定
     * @param entryTransferNumber 登録時振込番号
     */
    public function setEntryTransferNumber($entryTransferNumber) {
        $this->entryTransferNumber = $entryTransferNumber;
    }

    /**
     * 登録時振込番号の取得
     * @return 登録時振込番号
     */
    public function getEntryTransferNumber() {
        return $this->entryTransferNumber;
    }

    /**
     * 振込期限の設定
     * @param transferExpiredDate JAN振込期限3
     */
    public function setTransferExpiredDate($transferExpiredDate) {
        $this->transferExpiredDate = $transferExpiredDate;
    }

    /**
     * 振込期限の取得
     * @return 振込期限
     */
    public function getTransferExpiredDate() {
        return $this->transferExpiredDate;
    }

    /**
     * 口座管理方式の設定
     * @param accountManageType 口座管理方式
     */
    public function setAccountManageType($accountManageType) {
        $this->accountManageType = $accountManageType;
    }

    /**
     * 口座管理方式の取得
     * @return 口座管理方式
     */
    public function getAccountManageType() {
        return $this->accountManageType;
    }

    /**
     * 支店コードの設定
     * @param branchCode 支店コード
     */
    public function setBranchCode($branchCode) {
        $this->branchCode = $branchCode;
    }

    /**
     * 支店コードの取得
     * @return 口座管理方式
     */
    public function getBranchCode() {
        return $this->branchCode;
    }

    /**
     * 口座番号の設定
     * @param accountNumber 口座番号
     */
    public function setAccountNumber($accountNumber) {
        $this->accountNumber = $accountNumber;
    }

    /**
     * 口座番号の取得
     * @return 口座番号
     */
    public function getAccountNumber() {
        return $this->accountNumber;
    }

    /**
     * 銀行口座関連付け拒否フラグの設定
     * @param rejectBankAccount 銀行口座関連付け拒否フラグ
     */
    public function setRejectBankAccount($rejectBankAccount) {
        $this->rejectBankAccount = $rejectBankAccount;
    }

    /**
     * 銀行口座関連付け拒否フラグの取得
     * @return 銀行口座関連付け拒否フラグ
     */
    public function getRejectBankAccount() {
        return $this->rejectBankAccount;
    }

    /**
     * 商品IDマップサイズの取得
     * @return 商品IDマップのサイズ
     */
    public function getIdlistSize() {
        return count($this->idmap);
    }

    /**
     * 名前マップサイズの取得
     * @return 名前マップのサイズ
     */
    public function getNamelistSize() {
        return count($this->namemap);
    }

    /**
     * 個数マップサイズの取得
     * @return 個数マップのサイズ
     */
    public function getNumlistSize() {
        return count($this->nummap);
    }

    /**
     * 価格マップサイズの取得
     * @return 価格マップのサイズ
     */
    public function getUnitlistSize() {
        return count($this->unitmap);
    }

    /**
     * JANコードマップサイズの取得
     * @return 価格マップのサイズ
     */
    public function getJanCodelistSize() {
        return count($this->janCodemap);
    }

    /**
     * 商品IDの取得
     * @param index マップのインデックス
     * @return 商品ID
     */
    public function getIdmap($index) {
        return $this->idmap[$index];
    }

    /**
     * 名前の取得
     * @param index マップのインデックス
     * @return 商品名
     */
    public function getNamemap($index) {
        return $this->namemap[$index];
    }

    /**
     * 個数の取得
     * @param index マップのインデックス
     * @return 個数
     */
    public function getNummap($index) {
        return $this->nummap[$index];
    }

    /**
     * 価格の取得
     * @param index マップのインデックス
     * @return 価格
     */
    public function getUnitmap($index) {
        return $this->unitmap[$index];
    }

    /**
     * JanCodeの取得
     * @param index マップのインデックス
     * @return 価格
     */
    public function getJanCodemap($index) {
        return $this->janCodemap[$index];
    }

    /**
     * 決済方法の取得
     * @return string 決済方法
     */
    public function getSettlementType() {
        return $this->settlementType;
    }

    /**
     * 決済方法の設定
     * @param string $settlementType 決済方法
     */
    public function setSettlementType($settlementType) {
        $this->settlementType = $settlementType;
    }

    /**
     * 決済方法サブタイプの取得
     * @return string 決済方法サブタイプ
     */
    public function getSettlementSubType() {
        return $this->settlementSubType;
    }

    /**
     * 決済方法サブタイプの設定
     * @param string $settlementType 決済方法サブタイプ
     */
    public function setSettlementSubType($settlementSubType) {
        $this->settlementSubType = $settlementSubType;
    }

    /**
     * マーチャントIDの取得
     * @return string マーチャントID
     */
    public function getMerchantId() {
        return $this->merchantId;
    }

    /**
     * マーチャントIDの設定
     * @param string $merchantId マーチャントID
     */
    public function setMerchantId($merchantId) {
        $this->merchantId = $merchantId;
    }

    /**
     * 取引IDの取得
     * @return string 取引ID
     */
    public function getOrderId() {
        return $this->orderId;
    }

    /**
     * 取引IDの設定
     * @param string $orderId 取引ID
     */
    public function setOrderId($orderId) {
        $this->orderId = $orderId;
    }

    /**
     * SessionIDの取得
     * @return string SessionID
     */
    public function getSessionId() {
        return $this->sessionId;
    }

    /**
     * SessionIDの設定
     * @param string $sessionId SessionID
     */
    public function setSessionId($sessionId) {
        $this->sessionId = $sessionId;
    }

    /**
     * 購入金額の取得
     * @return string 購入金額
     */
    public function getAmount() {
        return $this->amount;
    }

    /**
     * 購入金額の設定
     * @param string $amount 購入金額
     */
    public function setAmount($amount) {
        $this->amount = $amount;
    }

    /**
     * カード売上フラグの取得
     * @return string カード売上フラグ
     */
    public function getCardCaptureFlag() {
        return $this->cardCaptureFlag;
    }

    /**
     * カード売上フラグの設定
     * @param string $cardCaptureFlag カード売上フラグ
     */
    public function setCardCaptureFlag($cardCaptureFlag) {
        $this->cardCaptureFlag = $cardCaptureFlag;
    }

    /**
     * モバイルEdy用ショップ名の取得
     * @return string モバイルEdy用ショップ名
     */
    public function getShopName() {
        return $this->shopName;
    }

    /**
     * モバイルEdy用ショップ名の設定
     * @param string $shopName モバイルEdy用ショップ名
     */
    public function setShopName($shopName) {
        $this->shopName = $shopName;
    }

    /**
     * Suica用商品名の取得
     * @return string Suica用商品名
     */
    public function getScreenTitle() {
        return $this->screenTitle;
    }

    /**
     * Suica用商品名の設定
     * @param string $screenTitle Suica用商品名
     */
    public function setScreenTitle($screenTitle) {
        $this->screenTitle = $screenTitle;
    }

    /**
     * 請求内容の取得
     * @return string 請求内容
     */
    public function getContents() {
        return $this->contents;
    }

    /**
     * 請求内容の設定
     * @param string $contents 請求内容
     */
    public function setContents($contents) {
        $this->contents = $contents;
    }

    /**
     * 請求内容カナの取得
     * @return string 請求内容カナ
     */
    public function getContentsKana() {
        return $this->contentsKana;
    }

    /**
     * 請求内容カナの設定
     * @param string $contentsKana 請求内容カナ
     */
    public function setContentsKana($contentsKana) {
        $this->contentsKana = $contentsKana;
    }

    /**
     * 支払取消期限の取得
     * @return string 支払取消期限
     */
    public function getTimelimitOfCancel() {
        return $this->timelimitOfCancel;
    }

    /**
     * 支払取消期限の設定
     * @param string $timelimitOfCancel 支払取消期限
     */
    public function setTimelimitOfCancel($timelimitOfCancel) {
        $this->timelimitOfCancel = $timelimitOfCancel;
    }

    /**
     * マーチャント生成ハッシュ値の取得
     * @return string マーチャント生成ハッシュ値
     */
    public function getMerchanthash() {
        return $this->merchanthash;
    }

    /**
     * マーチャント生成ハッシュ値の設定
     * @param string $merchanthash マーチャント生成ハッシュ値
     */
    public function setMerchanthash($merchanthash) {
        $this->merchanthash = $merchanthash;
    }

    /**
     * 決済結果通知先URLの取得
     * @return string 決済結果通知先URL
     */
    public function getFinishPaymentAccessUrl() {
        return $this->finishPaymentAccessUrl;
    }

    /**
     * 決済結果通知先URLの設定
     * @param string $finishPaymentReturnUrl 決済結果通知先URL
     */
    public function setFinishPaymentAccessUrl($finishPaymentAccessUrl) {
        $this->finishPaymentAccessUrl = $finishPaymentAccessUrl;
    }

    /**
     * 決済完了後戻りURLの取得
     * @return string 決済完了後戻りURL
     */
    public function getFinishPaymentReturnUrl() {
        return $this->finishPaymentReturnUrl;
    }

    /**
     * 決済完了後戻りURLの設定
     * @param string $finishPaymentReturnUrl 決済完了後戻りURL
     */
    public function setFinishPaymentReturnUrl($finishPaymentReturnUrl) {
        $this->finishPaymentReturnUrl = $finishPaymentReturnUrl;
    }

    /**
     * 未決済時戻りURLの取得
     * @return string 未決済時戻りURL
     */
    public function getUnfinishPaymentReturnUrl() {
        return $this->unfinishPaymentReturnUrl;
    }

    /**
     * 未決済時戻りURLの設定
     * @param string $unfinishPaymentReturnUrl 未決済時戻りURL
     */
    public function setUnfinishPaymentReturnUrl($unfinishPaymentReturnUrl) {
        $this->unfinishPaymentReturnUrl = $unfinishPaymentReturnUrl;
    }

    /**
     * 決済エラー済時戻りURLの取得
     * @return string 決済エラー時戻りURL
     */
    public function getErrorPaymentReturnUrl() {
        return $this->errorPaymentReturnUrl;
    }

    /**
     * 決済エラー時戻りURLの設定
     * @param string $errorPaymentReturnUrl 決済エラー時戻りURL
     */
    public function setErrorPaymentReturnUrl($errorPaymentReturnUrl) {
        $this->errorPaymentReturnUrl = $errorPaymentReturnUrl;
    }

    /**
     * 言語選択可否の取得
     * @return string 言語選択可否
     */
    public function getLangEnableFlag() {
        return $this->langEnableFlag;
    }

    /**
     * 言語選択可否の設定
     * @param string $langEnableFlag 言語選択可否
     */
    public function setLangEnableFlag($langEnableFlag) {
        $this->langEnableFlag = $langEnableFlag;
    }

    /**
     * 使用言語の取得
     * @return string 使用言語
     */
    public function getLang() {
        return $this->lang;
    }

    /**
     * 使用言語の設定
     * @param string $lang 使用言語
     */
    public function setLang($lang) {
        $this->lang = $lang;
    }

    /**
     * ダミー取引フラグの取得
     * @return string ダミー取引フラグ
     */
    public function getDummyPaymentFlag() {
        return $this->dummyPaymentFlag;
    }

    /**
     * ダミー取引フラグの設定
     * @param string $dummyPaymentFlag ダミー取引フラグ
     */
    public function setDummyPaymentFlag($dummyPaymentFlag) {
        $this->dummyPaymentFlag = $dummyPaymentFlag;
    }

    /**
     * 送料の取得
     * @return string 送料
     */
    public function getShippingAmount() {
        return $this->shippingAmount;
    }

    /**
     * 送料の設定
     * @param string $shippingAmount 送料
     */
    public function setShippingAmount($shippingAmount) {
        $this->shippingAmount = $shippingAmount;
    }

    /**
     * 商品合計金額の取得
     * @return string 商品合計金額
     */
    public function getCommodityAmount() {
        return $this->commodityAmount;
    }

    /**
     * 商品合計金額の設定
     * @param string $commodityAmount 商品合計金額
     */
    public function setCommodityAmount($commodityAmount) {
        $this->commodityAmount = $commodityAmount;
    }

    /**
     * 配送先郵便番号(先頭3桁)の取得
     * @return string 配送先郵便番号(先頭3桁)
     */
    public function getShippingZipCode1() {
        return $this->shippingZipCode1;
    }

    /**
     * 配送先郵便番号(先頭3桁)の設定
     * @param string $shippingZipCode1 配送先郵便番号(先頭3桁)
     */
    public function setShippingZipCode1($shippingZipCode1) {
        $this->shippingZipCode1 = $shippingZipCode1;
    }

    /**
     * 配送先郵便番号(先頭4桁)の取得
     * @return string 配送先郵便番号(先頭4桁)
     */
    public function getShippingZipCode2() {
        return $this->shippingZipCode2;
    }

    /**
     * 配送先郵便番号(先頭4桁)の設定
     * @param string $shippingZipCode2 配送先郵便番号(先頭4桁)
     */
    public function setShippingZipCode2($shippingZipCode2) {
        $this->shippingZipCode2 = $shippingZipCode2;
    }

    /**
     * ブラウザ側暗号鍵の取得
     * @return string ブラウザ側暗号鍵
     */
    public function getSettlementKey1A() {
        return $this->settlementKey1A;
    }

    /**
     * ブラウザ側暗号鍵の設定
     * @param string $settlementKey1A ブラウザ側暗号鍵
     */
    public function setSettlementKey1A($settlementKey1A) {
        $this->settlementKey1A = $settlementKey1A;
    }

    /**
     * 決済結果の取得
     * @return string 決済結果
     */
    public function getSettlementComplete() {
        return $this->settlementComplete;
    }

    /**
     * 決済結果の設定
     * @param string $settlementComplete 決済結果
     */
    public function setSettlementComplete($settlementComplete) {
        $this->settlementComplete = $settlementComplete;
    }

    /**
     * ActionFormのabstruct method
     * エラーチェック
     * @return エラーメッセージ（配列）
     */
    public function validate() {
        $log = $this->log->getMethodLog(__METHOD__);
        $errors = array();

        // 配送先郵便番号
        if (!$this->IsEmpty($this->getShippingZipCode())) {
            if (!preg_match("/^[0-9]+$/", $this->getShippingZipCode())) {
                $log->debug("非半角数字：配送先郵便番号");
                $errors[] = $this->actionMessage("error.shippingZipCode.forbiddenchar");
            }
        }

        // 商品情報
        if ($this->namemap == null || $this->getNamelistSize() == 0) {
            if (($this->idmap != null && $this->getIdlistSize() > 0)
                    || ($this->janCodemap != null && $this->getJanCodelistSize() > 0)
                    || ($this->nummap != null && $this->getNumlistSize() > 0)
                    || ($this->unitmap != null && $this->getUnitlistSize() > 0)
            ) {
                // 商品名に入力がない場合は商品情報は入力不可
                $this->logCommodityInfo();
                $errors[] = $this->actionMessage("error.commodityinfo.invalid");
            }
        } else {
            $commoditySize = $this->getNamelistSize();
            if ($this->nummap == null || $this->getNumlistSize() != $commoditySize
                    || $this->unitmap == null || $this->getUnitlistSize() != $commoditySize
                    || ($this->idmap != null && $this->getIdlistSize() != $commoditySize)
                    || ($this->janCodemap != null && $this->getJanCodelistSize() != $commoditySize)
            ) {
                // 商品名の入力数と個数、単価の入力数は一致していければならない
                // 商品IDとJAN_CODEは入力必須ではないが、入力している場合は商品名の入力数と一致していなければならない
                $this->logCommodityInfo();
                $errors[] = $this->actionMessage("error.commodityinfo.unnmatch");
            } else {
                for ($i = 0; $i < $commoditySize; $i++) {
                    if (!$this->IsNumeric($this->nummap[$i + 1]) || !$this->IsNumeric($this->nummap[$i + 1])) {
                        // 単価と個数は数値項目でなければならない
                        $this->logCommodityInfo();
                        $errors[] = $this->actionMessage("error.commodityinfo.notnumeric");
                    }
                }
            }
        }
        return $errors;
    }

    /**
     * 商品情報をログ出力する。
     */
    protected function logCommodityInfo() {
        $log = $this->log->getMethodLog(__METHOD__);
        if ($this->idmap != null && $this->getIdlistSize() > 0) {
            for ($i = 0; $i < $this->getIdlistSize(); $i++) {
                $log->info("COMMODITY_ID[" . $i + 1 . "] = " . $this->getIdmap($i + 1));
            }
        } else {
            $log->info("COMMODITY_ID is Empty");
        }

        if ($this->unitmap != null && $this->getUnitlistSize() > 0) {
            for ($i = 0; $i < $this->getUnitlistSize(); $i++) {
                $log->info("COMMODITY_UNIT[" . $i + 1 . "] = " . $this->getUnitmap($i + 1));
            }
        } else {
            $log->info("COMMODITY_UNIT is Empty");
        }

        if ($this->nummap != null && $this->getNumlistSize() > 0) {
            for ($i = 0; $i < $this->getNumlistSize(); $i++) {
                $log->info("COMMODITY_NUM[" . $i + 1 . "] = " . $this->getNummap($i + 1));
            }
        } else {
            $log->info("COMMODITY_NUM is Empty");
        }

        if ($this->namemap != null && $this->getNamelistSize() > 0) {
            for ($i = 0; $i < $this->getNamelistSize(); $i++) {
                $log->info("COMMODITY_NAME[" . $i + 1 . "] = " . $this->getNamemap($i + 1));
            }
        } else {
            $log->info("COMMODITY_NAME is Empty");
        }

        if ($this->janCodemap != null && $this->getJanCodelistSize() > 0) {
            for ($i = 0; $i < $this->getJanCodelistSize(); $i++) {
                $log->info("JAN_CODE[" . $i + 1 . "] = " . $this->getJanCodemap($i + 1));
            }
        } else {
            $log->info("JAN_CODE is Empty");
        }
    }

    /**
     * ActionFormのabstruct method
     */
    protected function setValue($name, $value) {
        $setMthod = 'set' . ucfirst($name);
        if (method_exists($this, $setMthod)) {
            $this->$setMthod($value);
        }
    }

    /**
     * ActionFormのabstruct method
     */
    protected function getValue($name) {
        $getMthod = 'get' . ucfirst($name);
        if (method_exists($this, $getMthod)) {
            return $this->$getMthod();
        } else {
            return null;
        }
    }
}
?>