<?php

/*
 * ConfirmActionManager.php
 *
 * 個人情報送信処理クラス
 */

/**
 * ConfirmActionManager class
 *
 * 入力情報の送信を行う
 * jp.co.veritrans.sample.ConfirmActionManagerより移植
 */
class ConfirmActionManager {

    /**
     * マーチャント情報
     * @var class MerchantInfo
     */
    private $merchant = null;
    /**
     * 取得したブラウザキー
     * @var string
     */
    private $browserKey = null;
    /**
     * 処理中に発生したメッセージ
     * @var string
     */
    private $message = array();
    /**
     * ログクラス
     */
    private $log = null;

    /**
     * コンストラクタ
     */
    public function __construct() {
        $this->log = new Logger(__CLASS__);
        $this->merchant = new MerchantInfo();
    }

    /**
     * VTWへ個人情報、商品情報を送信する
     * @param form 入力フォーム
     * @return 送信結果（true/false）
     */
    public function execute($form) {
        $log = $this->log->getMethodLog(__METHOD__);
        $log->info("送信処理開始");
        $purchaseData = $this->getPurchaseData($form);
        // HTTP POST送信
        $result = $this->sendPOST($purchaseData);

        return $result;
    }

    /**
     * 送信情報をPurchaseDataに登録する
     * @param CommodityDetail $form
     * @return PurchaseData
     */
    private function getPurchaseData($form) {
        $log = $this->log->getMethodLog(__METHOD__);
        $log->debug("送信情報作成開始");

        $data = new PurchaseData();
        $ch = new HashCodeCreater();

        // 商品情報クラスを生成
        $commodityDetails = $this->setCommodityDetail($form);

        // 全角文字が入るフィールドはVTW用文字コードに変換して登録する
        // 決済方法
        // ユーザが指定した決済種別
        $userSettlementType = $form->getSettlementType();
        // 利用可能な決済種別
        $settlementTypeList = array(VTW_SETTLEMENT_TYPE_CARD, VTW_SETTLEMENT_TYPE_CVS, VTW_SETTLEMENT_TYPE_EM, VTW_SETTLEMENT_TYPE_BANK, VTW_SETTLEMENT_TYPE_ORICOSC, VTW_SETTLEMENT_TYPE_VACC);
        // 利用可能な決済種別が指定されている場合、指定された種別をセット
        if (in_array($userSettlementType, $settlementTypeList)) {
            $log->debug("決済種別をユーザが指定：" . $userSettlementType);
            $data->setSettlementType($this->getSorpCode($userSettlementType));
        } else {
            // 決済種別はVTWサイトで選択
            $data->setSettlementType($this->getSorpCode(VTW_SETTLEMENT_TYPE_FREE));
        }

        // 決済方法サブタイプ
        $data->setSettlementSubType($this->getSorpCode($form->getSettlementSubType()));

        // マーチャントID
        $data->setMerchantId($this->getSorpCode($this->merchant->getMerchantID()));

        // 取引ID
        $data->setOrderId($this->getSorpCode($this->merchant->createOrderID()));

        // SessionID
        $data->setSessionId($this->getSorpCode(session_id()));

        // 購入金額
        $data->setAmount($this->getSorpCode($form->getAmount()));

        // カード売上フラグ
        $data->setCardCaptureFlag($this->getSorpCode($form->getCardCaptureFlag()));

        // モバイルEdy用ショップ名
        $data->setShopName($this->getSorpCode($form->getShopName()));

        // Suica用商品名
        $data->setScreenTitle($this->getSorpCode($form->getScreenTitle()));

        // 請求内容
        $data->setContents($this->getSorpCode($form->getContents()));

        // 請求内容カナ
        $data->setContentsKana($this->getSorpCode($form->getContentsKana()));

        // 支払取消期限
        $data->setTimelimitOfCancel($this->getSorpCode($form->getTimelimitOfCancel()));

        // 注文番号
        $oricoOrderNo = $this->createDummyOricoOrderNo();
        $data->setOricoOrderNo($this->getSorpCode($oricoOrderNo));

        // 配送先郵便番号
        $shippingZipCode = null;
        if (strlen($form->getShippingZipCode1()) > 0) {
            if (strlen($form->getShippingZipCode2()) > 0) {
                $shippingZipCode = $form->getShippingZipCode1() . "-" . $form->getShippingZipCode2();
            } else {
                $shippingZipCode = $form->getShippingZipCode1();
            }
        } elseif (strlen($form->getShippingZipCode2()) > 0) {
            $shippingZipCode = $form->getShippingZipCode2();
        } else {
            $shippingZipCode = "123-4567";
        }
        $data->setShippingZipCode($this->getSorpCode($shippingZipCode));

        // 送料
        $data->setShippingAmount($this->getSorpCode($form->getShippingAmount()));

        // 商品合計金額
        $data->setCommodityAmount($this->getSorpCode($form->getCommodityAmount()));


        // マーチャント生成ハッシュ値
        // ハッシュコードを生成
        $hashCode = $ch->getHash($data->getMerchantId(), $data->getSettlementType(), $data->getOrderId(), $data->getAmount());
        $data->setMerchantHash($this->getSorpCode($hashCode));
        $log->debug("Hash: {" . $data->getMerchantId() . ", " . $data->getSettlementType() . ", " . $data->getOrderId() . ", " . $data->getAmount() . "} ->{" . $data->getMerchantHash() . "}");

        // 決済結果通知先URL
        $data->setFinishPaymentAccessUrl($this->getSorpCode(FINISH_PAYMENT_ACCESS_URL));

        // 決済完了後戻りURL
        $data->setFinishPaymentReturnUrl($this->getSorpCode(FINISH_PAYMENT_RETURN_URL));

        // 未決済時戻りURL
        $data->setUnfinishPaymentReturnUrl($this->getSorpCode(UNFINISH_PAYMENT_RETURN_URL));

        // 決済エラー時戻りURL
        $data->setErrorPaymentReturnUrl($this->getSorpCode(ERROR_PAYMENT_RETURN_URL));

        // 言語選択可否
        $data->setLangEnableFlag($this->getSorpCode(LANG_ENABLE_FLAG));

        // 使用言語
        $data->setLang($this->getSorpCode(LANG));

        // ダミー取引フラグ
        $data->setDummyPaymentFlag($this->getSorpCode(DUMMY_PAYMENT_FLAG));

        // 商品情報を登録
        if (count($commodityDetails) > 0) {
            $data->setCommodityDetails($commodityDetails);
        }

        // 登録時振込番号
        $data->setEntryTransferNumber($this->getSorpCode($form->getEntryTransferNumber()));

        // 振込期限
        $data->setTransferExpiredDate($this->getSorpCode($form->getTransferExpiredDate()));

        // 口座管理方式
        $data->setAccountManageType($this->getSorpCode($form->getAccountManageType()));

        // 支店コード
        $data->setBranchCode($this->getSorpCode($form->getBranchCode()));

        // 口座番号
        $data->setAccountNumber($this->getSorpCode($form->getAccountNumber()));

        // 銀行口座関連付け拒否フラグ
        $data->setRejectBankAccount($this->getSorpCode($form->getRejectBankAccount()));

        // PayNowID使用フラグ
        $data->setPaynowidFlag($this->getSorpCode($form->getPaynowidFlag()));

        // 会員ID
        $data->setAccountId($this->getSorpCode($form->getAccountId()));

        // 生成されたハッシュをマーチャント情報に登録する
        $this->merchant->setMerchantHash($data->getMerchantHash());
        $this->merchant->setSessionId(session_id());
        return $data;
    }

    /**
     * 購入商品情報クラスをセット
     * @return 購入商品情報
     */
    private function setCommodityDetail(CommodityForm $commForm) {
        $log = $this->log->getMethodLog(__METHOD__);
        $log->info("購入商品情報クラスをセット");

        $commodityDetails = array();
        // 商品数
        $listsize = $commForm->getNamelistSize();
        for ($idx = 0; $idx < $listsize; $idx++) {
            $setId = null;
            if ($commForm->getIdmap($idx + 1) == null || $commForm->getIdlistSize() == 0) {
                $setId = DUMMY_COMMODITY_ID . $idx + 1;
            } else {
                $setId = $commForm->getIdmap($idx + 1);
            }

            $setJanCode = null;
            if ($commForm->getJanCodemap($idx + 1) == null || $commForm->getJanCodelistSize() == 0) {
                $setJanCode = DUMMY_COMMODITY_JANCODE . $idx + 1;
            } else {
                $setJanCode = $commForm->getJanCodemap($idx + 1);
            }

            // 商品情報を登録
            $commodityDetails[] = new CommodityDetail(
                            $this->getSorpCode($setId),
                            $this->getSorpCode($setJanCode),
                            $this->getSorpCode($commForm->getNamemap($idx + 1)),
                            $this->getSorpCode($commForm->getUnitmap($idx + 1)),
                            $this->getSorpCode($commForm->getNummap($idx + 1)));
        }
        $log->debug("購入商品件数：" . strval(count($commodityDetails)));
        return $commodityDetails;
    }

    /**
     * 文字コードをVTW送信用に変換する
     */
    protected function getSorpCode($value) {
        //return $value;
        return urlencode(mb_convert_encoding($value, VTW_SERVER_ENCODE, VTW_BASE_ENCODE));
    }

    /**
     * 文字コードをVTW受信用から変換する
     */
    protected function getBaseCode($value) {
        return urldecode(mb_convert_encoding($value, VTW_BASE_ENCODE, VTW_SERVER_ENCODE));
    }

    /**
     * HTTP POSTで送信する
     */
    private function sendPOST(PurchaseData $data) {
        $log = $this->log->getMethodLog(__METHOD__);
        $log->info("HTTP POST送信処理開始");

        $query = array();
        $ch = new HashCodeCreater();

        // POSTリクエストデータを作成
        // 決済方法
        $query['SETTLEMENT_TYPE'] = $data->getSettlementType();
        // 決済方法サブタイプ
        $query['SETTLEMENT_SUB_TYPE'] = $data->getSettlementSubType();
        // マーチャントID
        $query['MERCHANT_ID'] = $data->getMerchantID();
        // 取引ID
        $query['ORDER_ID'] = $data->getOrderID();
        // SessionID
        $query['SESSION_ID'] = $data->getSessionId();
        // 購入金額
        $query['AMOUNT'] = $data->getAmount();
        // カード売上フラグ
        $query['CARD_CAPTURE_FLAG'] = $data->getCardCaptureFlag();
        // モバイルEdy用ショップ名
        $query['SHOP_NAME'] = $data->getShopName();
        // Suica用商品名
        $query['SCREEN_TITLE'] = $data->getScreenTitle();
        // 請求内容
        $query['CONTENTS'] = $data->getContents();
        // 請求内容カナ
        $query['CONTENTS_KANA'] = $data->getContentsKana();
        // 支払取消期限
        $query['TIMELIMIT_OF_CANCEL'] = $data->getTimelimitOfCancel();
        // 注文番号
        $query['ORICO_ORDER_NO'] = $data->getOricoOrderNo();
        // マーチャント生成ハッシュ値
        $query['MERCHANTHASH'] = $data->getMerchantHash();
        // 決済結果通知先URL
        $query['FINISH_PAYMENT_ACCESS_URL'] = $data->getFinishPaymentAccessUrl();
        // 決済完了後戻りURL
        $query['FINISH_PAYMENT_RETURN_URL'] = $data->getFinishPaymentReturnUrl();
        // 未決済時戻りURL
        $query['UNFINISH_PAYMENT_RETURN_URL'] = $data->getUnfinishPaymentReturnUrl();
        // 決済エラー時戻りURL
        $query['ERROR_PAYMENT_RETURN_URL'] = $data->getErrorPaymentReturnUrl();
        // 言語選択可否
        $query['LANG_ENABLE_FLAG'] = $data->getLangEnableFlag();
        // 使用言語
        $query['LANG'] = $data->getLang();
        // ダミー取引フラグ
        $query['DUMMY_PAYMENT_FLAG'] = $data->getDummyPaymentFlag();
        // 配送先郵便番号
        $query['SHIPPING_ZIP_CODE'] = $data->getShippingZipCode();
        // 送料
        $query['SHIPPING_AMOUNT'] = $data->getShippingAmount();
        // 商品合計金額
        $query['COMMODITY_AMOUNT'] = $data->getCommodityAmount();

        // 商品情報を登録する
        $commodityDetails = $data->getCommodityDetails();
        if (is_array($commodityDetails) && count($commodityDetails) > 0) {
            $query['COMMODITY_ID'] = array();
            $query['COMMODITY_UNIT'] = array();
            $query['COMMODITY_NUM'] = array();
            $query['COMMODITY_NAME'] = array();
            $query['JAN_CODE'] = array();

            foreach ($commodityDetails as $detail) {
                $query['COMMODITY_ID'][] = $detail->getCommodityId();
                $query['COMMODITY_UNIT'][] = $detail->getCommodityUnit();
                $query['COMMODITY_NUM'][] = $detail->getCommodityNum();
                $query['COMMODITY_NAME'][] = $detail->getCommodityName();
                $query['JAN_CODE'][] = $detail->getJanCode();
            }
        }

        // 登録時振込番号
        $query['ENTRY_TRANSFER_NUMBER'] = $data->getEntryTransferNumber();
        // 振込期限
        $query['TRANSFER_EXPIRED_DATE'] = $data->getTransferExpiredDate();
        // 口座管理方式
        $query['ACCOUNT_MANAGE_TYPE'] = $data->getAccountManageType();
        // 支店コード
        $query['BRANCH_CODE'] = $data->getBranchCode();
        // 口座番号
        $query['ACCOUNT_NUMBER'] = $data->getAccountNumber();
        // 銀行口座関連付け拒否フラグ
        $query['REJECT_BANK_ACCOUNT'] = $data->getRejectBankAccount();
        if ($data->getPaynowidFlag() == "1") {
            $query['ACCOUNT_ID'] = $data->getAccountId();
        }
        // PayNowID使用フラグ
        $query['PAYNOWID_FLAG'] = $data->getPaynowidFlag();

        $log->debug("POST送信開始");
        // HTTP POSTで送信する
        $http = new HttpRequest(VTW_HTTP_POST_URI, HttpRequest::REQ_HTTP_POST);
        $http->setPostData($query, VTW_SERVER_ENCODE);
        $code = $http->sendRequest();

        // 正常終了（200 OK）が返ったか
        if (intval($code) == 200) {
            $log->debug("レスポンス解析");
            $merchantKey = null;
            $browserKey = null;
            $error_message = null;
            // レスポンスデータからマーチャントキー、ブラウザキーを取得
            $resBody = $http->getResponseBody();
            $bgodyLine = explode("\n", $resBody);
            foreach ($bgodyLine as $line) {
                $log->info("返信:" . $this->getBaseCode($line));
                if (preg_match('/^MERCHANT_ENCRYPTION_KEY=(.+)/', $line, $match)) {
                    $merchantKey = $match[1];
                } elseif (preg_match('/^BROWSER_ENCRYPTION_KEY=(.+)/', $line, $match)) {
                    $browserKey = $match[1];
                } elseif (preg_match('/^ERROR_MESSAGE=(.+)/', $line, $match)) {
                    $error_message = $match[1];
                }
            }
            if (!is_null($merchantKey) && !is_null($browserKey)) {
                $this->merchant->setSettlementKey1B($merchantKey);
                $this->merchant->setSettlementKey1A($browserKey);
                $log->info("キーが取得できた");
                return true;
            } elseif (!is_null($error_message)) {
                $this->message[] = $str = "VTWeb:" . $this->getBaseCode($error_message);
                return false;
            }
            $log->warn("キーが取得できない");
            $this->message[] = "決済処理が完了しませんでした";
        } else {
            $log->error("送信失敗 HTTP Code:" . strval($code));
            $this->message[] = "決済サーバに接続できません";
        }
        return false;
    }

    /**
     * マーチャント情報を取得
     */
    public function getMerchantInfo() {
        return $this->merchant;
    }

    /**
     * エラーメッセージを取得
     */
    public function getMessage() {
        return $this->message;
    }

    private function createDummyReceiptNo() {
        $now = date("YYYYmmddHHmmssSSS", time());
        $receiptNo = $now;
        for ($i = 0, $str = null; $i < 3; ) {
            $num = mt_rand(0x30, 0x7A);
            if ((0x30 <= $num && $num <= 0x39)||(0x41 <= $num && $num <= 0x5A)
                    ||(0x61 <= $num && $num <= 0x7A)){
                $now .= chr($num);
                $i++;
            }
        }
        return $receiptNo;
    }

    private function createDummyOricoOrderNo() {

        $time = microtime();
        $time_list = explode(' ',$time);
        $time_micro = explode('.',$time_list[0]);

        $date = new DateTime();
        $date_str = substr($date->format('YmdHis').$time_micro[1], 0, 17);

        $char_list_str = array_merge(range('a', 'z'), range('A', 'Z'));
        $random_string = '';
        foreach (array_rand($char_list_str, 3) as $k) {
            $random_string .= $char_list_str[$k];
        }

        return $date_str.$random_string;
    }

}

?>