<?php

// 共通インクルードファイル
require_once('common.php');
/*
 * orderIdをキーに個別データ管理を行うクラス
 * PostDataBoxHelperでファイルとのやり取りを行う
 */

class PostDataBox {

    /**
     * 取引ID
     * @var String
     */
    private $orderId = null;
    /**
     * 決済結果のステータス
     * @var String
     */
    private $mStatus = null;
    /**
     * エラーメッセージ
     * @var String
     */
    private $mErrMsg = null;
    /**
     * 結果コード
     * @var String
     */
    private $vResultCode = null;
    /**
     * キーファイルの登録キーとプロパティの対応マップ
     */
    private $paramMap = array(
        'MSTATUS' => 'mStatus',
        'MERRMSG' => 'mErrMsg',
        'VRESULTCODE' => 'vResultCode',
    );
    /**
     * ログクラス
     */
    private $log = null;

    /**
     * コンストラクタ
     */
    public function __construct($orderId = null, $dataBox = null) {
        $this->log = new Logger(__CLASS__);
        $log = $this->log->getMethodLog(__METHOD__);
        if (!is_null($orderId) && !is_null($dataBox)) {
            $this->setPostDataBox($orderId, $dataBox);
            $log->debug('orderId:' . $orderId);
        }
    }

    /**
     * 取引IDの設定
     * @return $orderId
     */
    public function getOrderId() {
        return $this->orderId;
    }

    /**
     * 取引IDの設定
     * @param $orderId
     */
    public function setOrderId($orderId) {
        $this->orderId = $orderId;
    }

    /**
     * 決済結果のステータスの設定
     * @return String mStatus
     */
    public function getMStatus() {
        return $this->mStatus;
    }

    /**
     * 決済結果のステータスの設定
     * @param String mStatus
     */
    public function setMStatus($mStatus) {
        $this->mStatus = $mStatus;
    }

    /**
     * エラーメッセージの取得
     * @return String mErrMsg
     */
    public function getMErrMsg() {
        return $this->mErrMsg;
    }

    /**
     * エラーメッセージの設定
     * @param String mErrMsg
     */
    public function setMErrMsg($mErrMsg) {
        $this->mErrMsg = $mErrMsg;
    }

    /**
     * 結果コードの取得
     * @return String vResultCode
     */
    public function getvResultCode() {
        return $this->vResultCode;
    }

    /**
     * 結果コードの設定
     * @param String vResultCode
     */
    public function setvResultCode($vResultCode) {
        $this->vResultCode = $vResultCode;
    }

    /**
     * キー情報を配列化する
     * @return array
     */
    public function getPostDataBox() {
        $log = $this->log->getMethodLog(__METHOD__);
        $dataBox = array();
        // マップからプロパティ名を取得
        foreach ($this->paramMap as $keyName => $paramName) {
            // getterから値を取得
            $getMthod = 'get' . ucfirst($paramName);
            if (method_exists($this, $getMthod)) {
                $value = $this->$getMthod();
            } else {
                $value = null;
            }
            // 値があれば配列に登録
            if (!is_null($value) && $value != '') {
                $dataBox[$keyName] = $value;
            }
        }
        return $dataBox;
    }

    /**
     * 配列からキー情報を登録する
     * @param $orderId
     * @param $dataBox
     */
    public function setPostDataBox($orderId, $dataBox) {
        $log = $this->log->getMethodLog(__METHOD__);
        $this->setOrderId($orderId);
        if (!is_array($dataBox)) {
            return;
        }
        foreach ($dataBox as $keyName => $keyValue) {
            // マップからプロパティ名を取得
            if (array_key_exists($keyName, $this->paramMap)) {
                // setterで値をセット
                $setMthod = 'set' . ucfirst($this->paramMap[$keyName]);
                if (method_exists($this, $setMthod)) {
                    $this->$setMthod($keyValue);
                }
            }
        }
    }

}

?>