<?php

// 共通インクルードファイル
require_once('common.php');

/**
 * orderIdをキーにデータ管理を行うヘルパークラス
 * ファイルには配列で格納するが、外部とはPostDataBoxクラスでアクセスする
 *
 * 注意：
 * 複数のorderIdからの同時アクセスには対応していません。
 */
class PostDataBoxHelper {

    /**
     * 読み込んだPostDataBox
     * 処理毎に再読み込みを行う
     */
    private $dataBox = array();
    /**
     * ログクラス
     */
    private $log = null;

    /**
     * コンストラクタ
     */
    public function __construct() {
        $this->log = new Logger(__CLASS__);
    }

    /**
     * PostDataBoxをファイルに書き出す
     */
    public function setDataBox(PostDataBox $dataBox) {
        $log = $this->log->getMethodLog(__METHOD__);
        $this->loadPostDataBox();
        $orderId = $dataBox->getOrderId();
        $this->databox[$orderId] = $dataBox->getPostDataBox();
        $this->savePostDataBox();
    }

    /**
     * 指定OrderIdのPostDataBoxをファイルから読み込む
     */
    public function getDataBox($orderId) {
        $log = $this->log->getMethodLog(__METHOD__);
        $dataBox = new PostDataBox();
        if ($this->loadPostDataBox()) {
            if (array_key_exists($orderId, $this->databox)) {
                $dataBox->setPostDataBox($orderId, $this->databox[$orderId]);
            }
        }

        return $dataBox;
    }

    /**
     * PostDataBox全体をファイルから読み込む
     */
    public function getDataArray() {
        $dataArray = array();
        if ($this->loadPostDataBox()) {
            foreach ($this->databox as $orderId => $databox) {
                $dataArray[$orderId] = new PostDataBox($orderId, $databox);
            }
        }
        return $dataArray;
    }

    /**
     * PostDataBoxの読み込み処理
     */
    private function loadPostDataBox() {
        $log = $this->log->getMethodLog(__METHOD__);
        try {
            if (file_exists(VTW_POST_DATA_BOX_FILE)) {
                $ser_databox = @ file_get_contents(VTW_POST_DATA_BOX_FILE);
                $this->databox = unserialize($ser_databox);
                return true;
            }
        } catch (Exception $e) {
            $log->error('キーファイル読み込み失敗：' . $e->getMessage());
        }
        return false;
    }

    /**
     * PostDataBoxの書き出し処理
     */
    private function savePostDataBox() {
        $log = $this->log->getMethodLog(__METHOD__);
        try {
            $ser_databox = serialize($this->databox);
            @ file_put_contents(VTW_POST_DATA_BOX_FILE, $ser_databox, LOCK_EX);
            return true;
        } catch (Exception $e) {
            $log->error('データファイル書き出し失敗：' . $e->getMessage());
        }
        return false;
    }

}

?>