<?php

// 共通インクルードファイル
require_once('common.php');

/**
 * class ResultCheckForm
 *
 */
class ResultCheckForm extends ActionForm {

    /**
     * 取引ID
     * @var String
     */
    private $orderId = null;
    /**
     * 決済結果のステータス
     * @var String
     */
    private $mStatus = null;
    /**
     * エラーメッセージ
     * @var String
     */
    private $mErrMsg = null;
    /**
     * 結果コード
     * @var String
     */
    private $vResultCode = null;
    /**
     * validate()で必須チェック対象とするパラメータリスト
     */
    private $validateParam = array('mStatus');
    /**
     * ログクラス
     */
    private $log = null;

    /**
     * コンストラクタ
     */
    public function __construct() {
        parent::__construct();
        $this->log = new Logger(__CLASS__);
    }

    /**
     * 取引IDの設定
     * @param orderId 取引ID
     */
    public function setOrderId($orderId) {
        $this->orderId = urldecode(mb_convert_encoding($orderId, VTW_BASE_ENCODE, VTW_SERVER_ENCODE));
        if (strlen($this->orderId) == 0) {
            $this->orderId = $orderId;
        }
    }

    /**
     * 取引IDの取得
     * @return String 取引ID
     */
    public function getOrderId() {
        return $this->orderId;
    }

    /**
     * 決済結果のステータスの取得
     * @return String 決済結果のステータス
     */
    public function getMStatus() {
        return $this->mStatus;
    }

    /**
     * 決済結果のステータスの設定
     * @param String mStatus
     */
    public function setMStatus($mStatus) {
        $this->mStatus = urldecode(mb_convert_encoding($mStatus, VTW_BASE_ENCODE, VTW_SERVER_ENCODE));
        if (strlen($this->mStatus) == 0) {
            $this->mStatus = $mStatus;
        }
    }

    /**
     * エラーメッセージの取得
     * @return String mErrMsg
     */
    public function getMErrMsg() {
        return $this->mErrMsg;
    }

    /**
     * エラーメッセージの設定
     * @param String mErrMsg
     */
    public function setMErrMsg($mErrMsg) {
        $this->mErrMsg = urldecode(mb_convert_encoding($mErrMsg, VTW_BASE_ENCODE, VTW_SERVER_ENCODE));
        if (strlen($this->mErrMsg) == 0) {
            $this->mErrMsg = $mErrMsg;
        }
    }

    /**
     * 結果コードの取得
     * @return String vResultCode
     */
    public function getvResultCode() {
        return $this->vResultCode;
    }

    /**
     * 結果コードの設定
     * @param String vResultCode
     */
    public function setvResultCode($vResultCode) {
        $this->vResultCode = urldecode(mb_convert_encoding($vResultCode, VTW_BASE_ENCODE, VTW_SERVER_ENCODE));
        if (strlen($this->vResultCode) == 0) {
            $this->vResultCode = $vResultCode;
        }
    }

    /**
     * ActionFormのabstruct method
     * エラーチェック
     * @return エラーメッセージ（配列）
     */
    public function validate() {
        $log = $this->log->getMethodLog(__METHOD__);
        $errors = array();

        // チェック対象プロパティのどれかが空であるか検査
        foreach ($this->validateParam as $param) {
            $value = $this->getValue($param);
            if ($this->IsEmpty($value)) {
                $errors[] = $param . " is empty";
                $log->info("パラメータ" . $param . "が未入力");
                break;
            }
        }
        return $errors;
    }

    /**
     * ActionFormのabstruct method
     */
    protected function setValue($name, $value) {
        $setMthod = 'set' . ucfirst($name);
        if (method_exists($this, $setMthod)) {
            $this->$setMthod($value);
        }
    }

    /**
     * ActionFormのabstruct method
     */
    protected function getValue($name) {
        $getMthod = 'get' . ucfirst($name);
        if (method_exists($this, $getMthod)) {
            return $this->$getMthod();
        } else {
            return null;
        }
    }

}

?>