<?php

// 共通インクルードファイル
require_once('common.php');

/**
 * class VTWDataValidate
 * VTWからのリクエストパラメータのチェックと、PostDataの登録を行う
 */
class VTWDataValidate {

    /**
     * ログクラス
     */
    private $log = null;
    private $resultForm = null;

    /*
     * コンストラクタ
     * @param $vtwPost TVWからのリクエストパラメータ
     */
    public function __construct($vtwPost) {
        $this->log = new Logger(__CLASS__);
        $log = $this->log->getMethodLog(__METHOD__);
        // リクエストパラメータを登録する
        $this->resultForm = new ResultCheckForm();
        $this->resultForm->setRequestArray($vtwPost);
        $log->debug("POSTデータ登録 取引ID：" . $this->resultForm->getOrderId());
        $log->debug("POSTデータ登録 ステータス：" . $this->resultForm->getMStatus());
        $log->debug("POSTデータ登録 エラーメッセージ：" . $this->resultForm->getMErrMsg());
        $log->debug("POSTデータ登録 結果コード：" . $this->resultForm->getvResultCode());
    }

    /**
     * VTWからのRequestの内容確認
     */
    public function resultCheck() {
        $log = $this->log->getMethodLog(__METHOD__);
        $log->debug("チェック開始");

        $validate = $this->resultForm->validate();
        // NULLチェック
        if (count($validate) > 0) {
            $log->info("チェックNG");
            return false;
        }

        // 登録されているマーチャント側暗号鍵情報を取得
        $dataHelper = new PostDataBoxHelper();
        $dataBox = $dataHelper->getDataBox($this->resultForm->getOrderId());
        // ステータス登録済みか
        $mstatus = $dataBox->getMStatus();
        if (!is_null($mstatus) && $mstatus != '') {
            $log->warn("ステータス登録済, 取引ID=" . $this->resultForm->getOrderId());
            return false;
        }

        $log->info("チェックOK");
        return true;
    }

    /**
     * クライアントから送信されてきたキーと、VTWから送信されてきたキーが一致するかをチェック
     */
    public function resultCrossCheck() {
        $log = $this->log->getMethodLog(__METHOD__);
        $log->debug("キー照合開始");
        if (is_null($this->resultForm->getOrderId())) {
            $log->info("取引IDが空");
            return false;
        }
        // 登録されている情報を取得
        $dataHelper = new PostDataBoxHelper();
        $dataBox = $dataHelper->getDataBox($this->resultForm->getOrderId());

        // kayBoxに値はあるか
        if(is_null($dataBox) || count($dataBox) == 0) {
            // キーが無い＝未登録の取引ID
            $log->info("取引ID未登録");
            return false;
        }

        $log->info("dataBox->getOrderId()=" . $dataBox->getOrderId());
        $log->info("dataBox->getMStatus()=" . $dataBox->getMStatus());
        $log->info("dataBox->getvResultCode()=" . $dataBox->getvResultCode());
        $log->info("this->resultForm->getOrderId()=" . $this->resultForm->getOrderId());
        $log->info("this->resultForm->getMStatus()=" . $this->resultForm->getMStatus());
        $log->info("this->resultForm->getvResultCode()=" . $this->resultForm->getvResultCode());

        // 取得したパラメータとクライアントからのキーを照合
        $result = 0;
        $result += $this->isMatch($dataBox->getOrderId(), $this->resultForm->getOrderId());
        $result += $this->isMatch($dataBox->getMStatus(), $this->resultForm->getMStatus());
        $result += $this->isMatch($dataBox->getvResultCode(), $this->resultForm->getvResultCode());

        if ($result == 3) {
            $log->info("照合OK");
            return true;
        } else {
            $log->info("照合NG");
            return false;
        }
    }

    /**
     * マーチャント側暗号鍵情報を新規登録
     */
    public function signUpPostDatabox() {
        $log = $this->log->getMethodLog(__METHOD__);
        $log->debug("キー新規登録開始");
        if (is_null($this->resultForm->getOrderId())) {
            $log->debug("取引IDが見つかりません");
            return;
        }
        // 登録されているマーチャント側暗号鍵情報を取得
        $dataHelper = new PostDataBoxHelper();
        $dataBox = $dataHelper->getDataBox($this->resultForm->getOrderId());
        // 取得したパラメータを登録
        $dataBox->setOrderId($this->resultForm->getOrderId());
        $dataBox->setMStatus($this->resultForm->getMStatus());
        $dataBox->setvResultCode($this->resultForm->getvResultCode());

        // マーチャント側暗号鍵情報を新規登録
        $dataHelper->setDataBox($dataBox);
        $log->info("dataBox->getOrderID()=" . $dataBox->getOrderID());
        $log->info("dataBox->getMStatus()=" . $dataBox->getMStatus());
        $log->info("dataBox->getvResultCode()=" . $dataBox->getvResultCode());

        $log->info("キー新規登録完了");
    }

    /**
     * resultFormの取得
     * @return ResultCheckForm resultForm
     */
    public function getResultForm() {
        return $this->resultForm;
    }

    /**
     * 2つの値が一致しているかどうか比較
     * ※互いにnullの場合は 偽(0) とする
     *
     * @param val1 比較対象1
     * @param val2 比較対象2
     * return result 一致すれば1、しなければ0
     */
    public function isMatch($val1, $val2) {
        return (!is_null($val1) and strcmp($val1, $val2) == 0) ? 1 : 0;
    }
}

?>