<?php

// hidden情報から遷移先を決定する
$iFrameFlag = false;    // インラインフレーム遷移フラグ
if(isset($_POST[ 'DisplayType' ]) && $_POST['DisplayType'] == "iframe"){
    $iFrameFlag = true;
}

// 共通インクルードファイル
require_once('common.php');

// セッションを開始
session_start();

$log = new Logger(__FILE__);

// セッションに登録されていなければ、初期ページに飛ばす
if (!isset($_SESSION['commodityName1'])) {
    $log->info("セッションに購入商品が登録されていない→商品購入ページへ");
    if ($iFrameFlag) {
        header("Location: if_purchase.php");
    } else {
        header("Location: purchase.php");
    }
    exit();
}

// エラー発生フラグ
$error = false;

// フォームオブジェクトを生成
$form = new EmForm();
$form->setSettlementType(VTW_SETTLEMENT_TYPE_EM);

// POSTされたフォームを登録
$form->setRequestArray($_POST);
// 入力チェックを行う
$errors = $form->validate();

// エラーが発生しているか
if (count($errors) > 0) {
    $log->debug("入力チェックエラーあり");
    $error = true;
} else {
    $log->debug("入力チェックエラーなし");
}

// エラーが発生したか
if ($error) {
    $log->info("個人情報入力画面へ");
    // 入力画面を呼び出して終了する
    session_write_close(); // entry_em.php内でsession_start()を呼ぶのでここで閉じておく
    if ($iFrameFlag) {
        include_once('./if_entry_em.php');
    } else {
        include_once('./entry_em.php');
    }
    exit();
}

$suicaList = array(EM_SUBTYPE_SUICA_MOBILE, EM_SUBTYPE_SUICA_PC);

$subType = $form->getSettlementSubType();
$log->info("電子マネー種別：" . $subType);

if (is_null($subType) || $subType == '') {
    // 画面タイトル
    $form->setScreenTitle(SCREEN_TITLE);

    // 支払取消期限
    // この項目はWAONしか使用しないので設定もWAON用を流用
    $cancelLimit = intval(TIMELIMIT_OF_CANCEL);
    $limitdate = getLimitDateStr($cancelLimit);
    $log->info("支払取消期限：" . $limitdate);
    $form->setTimelimitOfCancel($limitdate);
} else if (strcmp(EM_SUBTYPE_EDY_PC, $subType) == 0) {
    // 支払期限は10日固定なのでセットしない
} else if (strcmp(EM_SUBTYPE_EDY_MOBILE, $subType) == 0) {
    // ショップ名
    $form->setShopName(SHOP_NAME);
} else if (in_array($subType, $suicaList)) {
    // 画面タイトル
    $form->setScreenTitle(SCREEN_TITLE);
} else if (strcmp(EM_SUBTYPE_WAON_PC, $subType) == 0 || strcmp(EM_SUBTYPE_WAON_MOBILE, $subType) == 0) {
    // 支払取消期限
    $cancelLimit = intval(TIMELIMIT_OF_CANCEL);
    $limitdate = getLimitDateStr($cancelLimit);
    $log->info("支払取消期限：" . $limitdate);
    $form->setTimelimitOfCancel($limitdate);
}

// セッションにパラメータを登録する
$_SESSION['EmForm'] = $_POST;

// 個人情報を送信する
$log->info("個人情報送信");
$action = new ConfirmActionManager();
if ($action->execute($form)) {
    $log->info("個人情報送信完了");
    // マーチャントキーを取得する
    $merchant = $action->getMerchantInfo();
} else {
    $log->info("個人情報送信失敗");

    $errors = $action->getMessage();
    $log->info("個人情報入力画面へ");
    // 入力画面を呼び出して終了する
    session_write_close(); // entry.php内でsession_start()を呼ぶのでここで閉じておく
    if ($iFrameFlag) {
        include_once('if_entry_em.php');
    } else {
        include_once('entry_em.php');
    }
    exit();
}

$log->info("VTWへの遷移画面へ");
session_write_close();
if ($iFrameFlag) {
    include_once('../if_jump.php');
} else {
    include_once('../jump.php');
}
?>